/* gaussElim.cpp is a driver program for Gaussian Elimination.
 * 
 * Input:  a series of linear equation coefficients
 * Output: the solution of the linear equation or a "singular
 *           system" message
 * Joel Adams, Fall 1996 at Calvin College.
 ***************************************************************/
 
#include <iostream>         // cout, cin, ...
#include <cmath>            // abs()
#include <cstdlib>          // exit()
#include "GaussianMatrix.h" // Matrix subclass
 
int main()
{
  cout << "This program solves a linear system "
          "using Gaussian Elimination. \n";
 
  int numEquations;	
  for (;;)
  {
      cout << "\nPlease enter the number of equations in the system: ";
      cin >> numEquations;
      if (numEquations > 1) break;
      cerr << "\n*** At least two equations are needed ...\n";
  }

  cout << "\nPlease enter the coefficient matrix row-by-row...";
  GaussianMatrix gMatrix(numEquations, numEquations+1);
  gMatrix.readCoefficientMatrix(cin);
  
  cout << "\nNow enter the constant vector:\n";
  gMatrix.readConstantVector(cin);
  
  bool isSingular = gMatrix.reduce();
  
  if (isSingular)
  {
      cerr << "\n*** gaussianElimination: Coefficient Matrix is (nearly) singular!\n";
      exit (0);
  }
 
  Matrix solutionVector = gMatrix.solve();
  
  cout << "\nThe solution vector (x1, x2, ...)  for this system is:\n\n"
       << solutionVector << endl;
}
